@@ -21,7 +21,7 @@
 #ifndef MENUMODEL_H
 #define MENUMODEL_H
 
-#include <QtCore/QAbstractItemModel>
+#include <QAbstractItemModel>
 #include "systemsettingsview_export.h"
 
 class MenuItem;
@@ -41,6 +41,24 @@ class SYSTEMSETTINGSVIEW_EXPORT MenuModel : public QAbstractItemModel
     Q_OBJECT
 
 public:
+    enum Roles {
+        MenuItemRole = Qt::UserRole,
+
+        /**
+        * Role used to request the keywords to filter the items when searching.
+        */
+        UserFilterRole,
+
+        /**
+        * Role used to request the weight of a module, used to sort the items.
+        */
+        UserSortRole,
+
+        DepthRole,
+
+        IsCategoryRole
+    };
+
     /**
      * Creates a MenuModel using the MenuItem specified. The MenuItem must always be valid
      * throughout the life of the MenuModel, otherwise it will cause crashes.
@@ -48,12 +66,14 @@ public:
      * @param menuRoot The MenuItem to use as the basis for providing information.
      * @param parent The QObject to use as a parent of the MenuModel.
      */
-    explicit MenuModel( MenuItem * menuRoot, QObject *parent = 0 );
+    explicit MenuModel( MenuItem * menuRoot, QObject *parent = nullptr );
 
     /**
      * Destroys the MenuModel. The menuRoot will not be destroyed.
      */
-    ~MenuModel();
+    ~MenuModel() override;
+
+    QHash<int, QByteArray> roleNames() const override;
 
     /**
      * Please see Qt QAbstractItemModel documentation for more details.\n
@@ -63,7 +83,7 @@ public:
      * @param role The information role you want information about.
      * @returns The data requested for the role provided from the QModelIndex provided.
      */
-    QVariant data( const QModelIndex &index, int role ) const;
+    QVariant data( const QModelIndex &index, int role ) const override;
 
     /**
      * Please see Qt QAbstractItemModel documentation for more details.\n
@@ -72,7 +92,7 @@ public:
      *
      * @returns The flags for the QModelIndex provided.
      */
-    Qt::ItemFlags flags( const QModelIndex &index ) const;
+    Qt::ItemFlags flags( const QModelIndex &index ) const override;
 
     /**
      * Please see Qt QAbstractItemModel documentation for more details.\n
@@ -83,7 +103,7 @@ public:
      * @param parent The parent of the requested child.
      * @returns The QModelIndex for the item requested.
      */
-    QModelIndex index( int row, int column, const QModelIndex &parent = QModelIndex() ) const;
+    QModelIndex index( int row, int column, const QModelIndex &parent = QModelIndex() ) const override;
 
     /**
      * Please see Qt QAbstractItemModel documentation for more details.\n
@@ -92,7 +112,7 @@ public:
      * @param index The child of the parent.
      * @returns A QModelIndex for the parent.
      */
-    QModelIndex parent( const QModelIndex &index ) const;
+    QModelIndex parent( const QModelIndex &index ) const override;
 
     /**
      * Please see Qt QAbstractItemModel documentation for more details.\n
@@ -101,7 +121,7 @@ public:
      * @param parent The QModelIndex the count is performed on.
      * @returns The number of rows ( children ) in the parent.
      */
-    int rowCount( const QModelIndex &parent = QModelIndex() ) const;
+    int rowCount( const QModelIndex &parent = QModelIndex() ) const override;
 
     /**
      * Please see Qt QAbstractItemModel documentation for more details.\n
@@ -110,7 +130,7 @@ public:
      * @param parent This is ignored, as the count is always 1.
      * @returns The number of columns ( 1 ) in the parent.
      */
-    int columnCount( const QModelIndex &parent = QModelIndex() ) const;
+    int columnCount( const QModelIndex &parent = QModelIndex() ) const override;
 
     /**
      * Makes the MenuItem specified be hidden from the list, while still showing its children.\n
@@ -130,16 +150,6 @@ public:
      */
     void removeException( MenuItem * exception );
 
-    /**
-     * Role used to request the keywords to filter the items when searching.
-     */
-    static const int UserFilterRole;
-
-    /**
-     * Role used to request the weight of a module, used to sort the items.
-     */
-    static const int UserSortRole;
-
 protected:
     /**
      * Provides the MenuItem which is used internally to provide information.
